// storage/screens/ConversationsList.jsx
// Asume que React, globalFirestoreDb, appId, Avatar y formatLastSeen están disponibles globalmente.
const ConversationsList = ({ user, showErrorModal, navigateToChat }) => {
    const { useState, useEffect } = React; // Usar React para desestructurar hooks
    const [conversations, setConversations] = useState([]);

    useEffect(() => {
        if (!globalFirestoreDb) {
            setConversations([]); 
            return;
        }

        if (!user || !user.uid || typeof user.uid !== 'string') {
            console.log("ConversationsList: Usuario o user.uid inválido. Saltando configuración del listener de Firestore.", { user, uid: user ? user.uid : 'N/A' });
            setConversations([]); 
            return;
        }

        console.log("ConversationsList: Configurando listener de Firestore para User ID:", user.uid);
        const q = globalFirestoreDb.collection('artifacts').doc(appId).collection("public").doc("data").collection("chats")
                                .where("participants", "array-contains", user.uid);
        
        const unsubscribe = q.onSnapshot(snapshot => {
            let fetchedConversations = snapshot.docs.map(doc => {
                const data = doc.data();
                const otherParticipantId = data.participants.find(pId => pId !== user.uid);
                return {
                    id: doc.id,
                    ...data,
                    recipientId: otherParticipantId,
                    recipientName: 'Cargando nombre...', 
                    recipientStatus: 'desconocido', 
                    recipientLastSeen: null, 
                    recipientProfilePictureUrl: null 
                };
            });

            fetchedConversations = fetchedConversations.filter(conv => 
                conv.lastMessage !== null && (!conv.hiddenFor || !conv.hiddenFor.includes(user.uid))
            );

            fetchedConversations.sort((a, b) => {
                const timestampA = a.lastMessage && a.lastMessage.timestamp ? a.lastMessage.timestamp.toDate().getTime() : 0;
                const timestampB = b.lastMessage && b.lastMessage.timestamp ? b.lastMessage.timestamp.toDate().getTime() : 0;
                return timestampB - timestampA;
            });
            
            setConversations(fetchedConversations);

            const fetchRecipientData = async (convsToUpdate) => {
                const updatedConvsPromises = convsToUpdate.map(async (conv) => {
                    if (conv.type === 'individual' && conv.recipientId) {
                        const userDoc = await globalFirestoreDb.collection('artifacts').doc(appId).collection('users').doc(conv.recipientId).get();
                        if (userDoc.exists) {
                            const userData = userDoc.data();
                            return { 
                                ...conv, 
                                recipientName: userData.displayName || userData.email,
                                recipientStatus: userData.status || 'offline',
                                recipientLastSeen: userData.lastSeen, 
                                recipientProfilePictureUrl: userData.profilePictureUrl || null
                            };
                        }
                    }
                    return conv; 
                });
                const resolvedUpdatedConvs = await Promise.all(updatedConvsPromises);
                setConversations(resolvedUpdatedConvs); 
            };

            if (fetchedConversations.length > 0) {
                fetchRecipientData(fetchedConversations);
            }

        }, err => {
            console.error("Error al cargar conversaciones:", err);
            showErrorModal("Error al cargar conversaciones: " + err.message);
        });

        return () => unsubscribe();
    }, [user, globalFirestoreDb, showErrorModal]);


    return (
        <div className="w-full space-y-4">
            <h3 className="text-lg sm:text-xl font-semibold mb-3 sm:mb-4 text-gray-800">Tus Conversaciones</h3>
            {conversations.length === 0 ? (
                <p className="text-center text-sm sm:text-base text-gray-500">No tienes conversaciones. ¡Busca un usuario para empezar!</p>
            ) : (
                <ul className="space-y-2 sm:space-y-3">
                    {conversations.map(conv => (
                        <li
                            key={conv.id}
                            className="flex items-center justify-between p-2 sm:p-3 bg-white rounded-lg shadow cursor-pointer hover:bg-gray-100 transition duration-150 ease-in-out" 
                            onClick={() => navigateToChat(conv.id, conv.recipientId, conv.recipientName)}
                        >
                            <div className="flex items-center flex-1">
                                <Avatar displayName={conv.recipientName} profilePictureUrl={conv.recipientProfilePictureUrl} size="medium" />
                                <div className="ml-2 sm:ml-3 flex-1 overflow-hidden">
                                    <div className="font-semibold text-base sm:text-lg text-gray-900 flex items-center"> 
                                        <span className="truncate">{conv.type === 'individual' ? conv.recipientName : conv.name || 'Chat Grupal'}</span>
                                        <span className="ml-1 sm:ml-2 text-xs text-gray-500">
                                            {formatLastSeen(conv.recipientStatus, conv.recipientLastSeen)}
                                        </span>
                                        {formatLastSeen(conv.recipientStatus, conv.recipientLastSeen) === 'En línea' && (
                                            <span className="w-2 h-2 ml-1 sm:ml-2 bg-green-500 rounded-full inline-block animate-pulse"></span>
                                        )}
                                    </div>
                                    <p className="text-xs sm:text-sm text-gray-700 truncate">
                                        {conv.lastMessage ? `${conv.lastMessage.senderName}: ${conv.lastMessage.content}` : 'No hay mensajes aún.'}
                                    </p>
                                    {conv.lastMessage && (
                                        <div className="text-xs text-gray-500 mt-1">
                                            {conv.lastMessage.timestamp ? new Date(conv.lastMessage.timestamp.toDate()).toLocaleTimeString([], { hour: '2-digit', minute: '2-digit' }) : 'Enviando...'}
                                        </div>
                                    )}
                                </div>
                            </div>
                        </li>
                    ))}
                </ul>
            )}
        </div>
    );
};
